#
# spec file for package bzflag
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir %{_localstatedir}/adm/fillup-templates
%endif
Name:           bzflag
Version:        2.4.26
Release:        2.5
Summary:        3D Networked Multiplayer Tank Battle Game
License:        GPL-2.0-or-later
Group:          Amusements/Games/3D/Shoot
URL:            https://www.bzflag.org/
Source:         https://download.bzflag.org/bzflag/source/%{version}/bzflag-%{version}.tar.gz
Source2:        rc.bzflagserver
Source3:        %{name}-maps.tar.bz2
Source4:        sysconfig.bzflagserver-bzflag
Source5:        %{name}.desktop
Source6:        %{name}.png
Source7:        bzflagserver.service
# PATCH-MISSING-TAG -- See http://wiki.opensuse.org/openSUSE:Packaging_Patches_guidelines
Patch0:         %{name}-1.10.4-ncursespollution.patch
BuildRequires:  bc
BuildRequires:  curl-devel
BuildRequires:  fdupes
BuildRequires:  freeglut-devel
BuildRequires:  gcc-c++
BuildRequires:  libcares-devel
BuildRequires:  libdrm-devel
BuildRequires:  ncurses-devel
BuildRequires:  systemd-rpm-macros
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(sdl2)
Requires(pre):  %fillup_prereq
%{?systemd_ordering}
%if 0%{?sles_version}
BuildRequires:  glew-devel
%else
BuildRequires:  pkgconfig(glew)
%endif
BuildRequires:  zlib-devel

%description
BZFlag is a 3D multiplayer tank battle game that allows users to play
against each other in a networked environment. Because it makes heavy
use of 3D graphics (OpenGL), a fast CPU or a supported 3D video card is
heavily recommended.

Find server maps in /usr/share/bzflag/maps.

%prep
%autosetup -p1 -a 3
cp %{SOURCE2} .
cp %{SOURCE7} .

%build
%configure \
    --disable-dependency-tracking \
    --libdir=%{_libdir}/%{name} \
    --disable-static
%make_build all

%pre
%service_add_pre bzflagserver.service

%preun
%service_del_preun bzflagserver.service

%post
%fillup_only -an bzflagserver
%service_add_post bzflagserver.service

%postun
%service_del_postun bzflagserver.service

%install
#Init script for the BZFlag server
mkdir -p %{buildroot}%{_datadir}/%{name}/scripts
install -D -m 755 %{SOURCE2} %{buildroot}%{_datadir}/%{name}/scripts/rcbzflagserver
install -D -m 644 %{SOURCE7} %{buildroot}%{_unitdir}/bzflagserver.service
%make_install MKDIR_P="mkdir -p --"
install -D -m 644 %{SOURCE4} %{buildroot}%{_fillupdir}/sysconfig.bzflagserver-bzflag
mkdir -p %{buildroot}%{_datadir}/%{name}/maps
install -m 644 maps/*bzmap %{buildroot}%{_datadir}/%{name}/maps
install -D -m 644 %{SOURCE6} %{buildroot}%{_datadir}/pixmaps/bzflag.png
%suse_update_desktop_file -i %{name}
%fdupes %{buildroot}

%files
%license COPYING
%doc AUTHORS PORTING README DEVINFO
%doc README.Linux misc/bzfs.conf ChangeLog
%{_datadir}/%{name}/
%{_datadir}/%{name}/scripts/
%{_datadir}/bzflag/scripts/rcbzflagserver
%{_unitdir}/bzflagserver.service
%{_bindir}/*
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png
%{_mandir}/man5/*
%{_mandir}/man6/*
%{_fillupdir}/sysconfig.bzflagserver-bzflag
%{_libdir}/%{name}/

%changelog
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Sun Nov 20 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 2.4.26
  * Audio pops should be fixed.
  * Positional audio in observer mode now uses the camera direction
  * Fixed a regression that caused some textures to render skewed.
  * Fixed the Machine Gun firing continuously when the mouse wheel
    is used to fire.
* Wed Nov  9 2022 Dmitriy Perlow <dap.darkness@gmail.com>
- BuildRequre sdl2 stuff via pkgconfig(*).
* Sat Mar 12 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 2.4.24
  * Don't crash when removing the BZFS Cron server-side player
  * Announce who adjusted the countdown with /modcount
  * Add support for Apple silicon builds
  * Work around an SDL 2.0.20 event handling regression
  * Do not explicitly link to X11 when using SDL
- Run spec-cleaner
- Fix encoding of rc.bzflagserver, changed to UTF8
- Fix obsolete-suse-version-check warning
* Thu Aug 26 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s). Modified:
  * bzflagserver.service
* Sun Feb 28 2021 Martin Hauke <mardnh@gmx.de>
- Update to 2.4.22
  * Fix many issues with SDL 2 window management.
  * The playHistoryTracker plugin now tracks kills correctly.
  * Local shotID was not being set in bz_eShotFiredEvent.
  * Send active autopilot statuses to a joining player.
  * Fix solo bots being kicked when rejoining to a server.
  * Fix the backspace key not working on the bzadmin Curses menu.
* Tue Jun 23 2020 Mathias Homann <Mathias.Homann@opensuse.org>
- Update to 2.4.20
  * Reorganization of the menus to improve usability - Scott Wichser
  * Add bz_isWithinWorldBoundaries to API - Vladimir Jimenez
  * Use teleporter names in /saveworld .obj exports - Vladimir Jimenez
  * Add bz_getSpawnPointWithin to API - Vladimir Jimenez
  * Fix NetHandler compiler errors on Alpine Linux - Jim Melton
  * Significantly improve platform-dependent header imports - Jim Melton
  * Only perform texture conversion to internal format once - Alfredo Tupone, Scott Wichser
  * Removal of never used logic for expiring builds - Zehra
  * Radar size and console height are controlled with BZDB variables - The Noah
  * Add bz_getNearestFlagSafetyZone to the API - Vladimir Jimenez
  * Don't allow hunt to be used when not connected to a server - Zehra
  * Improve vsync settings with SDL2 - Joshua Bodine
  * Ignore the -NSDocumentRevisionsDebugMode YES option in Xcode - Joshua Bodine
  * Add Slovak translation - Jose Riha, Scott Wichser
  * Use a greyscale color scale based on relative height when colored radar shots are disabled - Alfredo Tupone
  * Sort locally discovered servers to the top of the server list - Scott Wichser
  * Add the Open Free For All mode to the Start Server menu - Scott Wichser
  * Remove ineffective performance tests and just default to "modern" settings - Scott Wichser
  * Change default settings to better suit first time players - Scott Wichser
  * Standardize the rabbit game mode name to "Rabbit Chase" - Scott Wichser
  * Do not scale NPOT textures when OpenGL supports them - Alfredo Tupone
  * Generate mipmaps with OpenGL 1.4 extension - Alfredo Tupone
  * Fixed SDL 1.2 builds on macOS - Joshua Bodine
  * Force zbuffer for Experimental quality - Alfredo Tupone
  * Use GLEW to detect GL_EXT_texture_edge_clamp - Alfredo Tupone
  * Add support for storing arbitrary data in API player records - Jeff Myers
  * Fix API string utility functions sometimes losing values - Vladimir Jimenez
  * Add new bz_ePlayerDeathFinalizedEvent API event - Vladimir Jimenez
  * Display Time-per-Frame with 2 decimal digits and averaged over time - Alfredo Tupone
  * Output correct error when loading a nonexistent bzfs plugin - Vladimir Jimenez
  * Remove obsolete bzfs option from Start Server menu on Windows - Scott Wichser
* Sat May 18 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.4.16
  * Send MsgFlagGrab before API event is called
  * Correctly unmuted when paused and killed by server
  * Format codebase to allman style
  * Use GLEW for obtaining OpenGL entry points and checking for
    extensions
  * Revert a80ab87 (truncation warning fix) as that generated broken
    replay file headers. Detect and work around that bad header.
  * Use pkg-config, if available, to detect ncurses
- Update to version 2.4.14
  * Add new bz_eAllowServerShotFiredEvent to the API
  * Fix antialiasing when starting the client windowed
  * Update the Windows icon file to include larger icons
  * Treat the number pad keys uniquely for key mapping with SDL2
  * Better cpu selection for x86_64
  * Fix build with enable-profile
  * Add safety check when getting flags (bzfs)
  * Add min/../max to drawTime - Alfredo Tupone
  * Fix the -configdir option for the client
  * Improve support for custom BZDB vars in plug-ins
  * Fix truncation warnings
  * Add new bz_ePermissionModificationEvent to the API
  * Introduce new 'showMotto' permission
  * Fix gcc warnings and code formatting
  * Remove old BitmapFont renderer
  * Add new bz_eServerShotFiredEvent to the API
  * Revamp the world weapon API entirely
  * Add PLAYER-MOTTO output to logDetail plugin
  * Display remaining ban time when a banned player connects
  * Punitive messages no longer display admin callsigns
  * Slash commands in the API now know destination channel
  * Fix ability to bind a key with a modifier through menu
  * Disallow -helpmsg from world files
* Mon Mar 25 2019 Jan Engelhardt <jengelh@inai.de>
- Add %%systemd_ordering for %%service_*.
* Tue Feb 26 2019 josef.moellers@suse.com
- Replaced the sysv init script by a systemd unit file
  Due to the complexity of the init script, the script is still
  used to start/stop the server. Note that the init script
  and the systemd unit file are not part of upstream!
  [bsc#1115940, bzflagserver.service]
* Thu Dec 21 2017 bwiedemann@suse.com
- Update to version 2.4.12
  * See /usr/share/doc/packages/bzflag/ChangeLog for full details
  * Added many new functions to API
  * Added plugins:
  * superUser
  * bzfscron
  * serverSidePlayerSample
  * CustomZoneSample
  * make build fully reproducible (boo#1047218)
- Drop upstream bzflag-char-signedness.patch
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Wed Apr 17 2013 joop.boonen@opensuse.org
- Update to version 2.4.2
  * Added UPnP option to configure server networking - Alfredo Tupone
  * Added an option to have both leading and lagging radar shot lines - David Anderson
  * Prevent prohibited solo bots from joining, rather than kick afterward - Scott Wichser, Jeff Makey
  * Add thiefControl plugin which prevents stealing flags from teammates - Bernt Hansen, Scott Wichser
  * Preserve shot-limited flag behavior on final shot - David Anderson
  * Remove the -zoom command line option from bzflag - Jeff Makey
  * Provide observer team chat in OpenFFA mode - David Anderson
  * Add fairCTF plugin - Chris Wible
  * Allow plugins to specify a color when firing world weapons - Chris Wible
  * Add option for chat on the left and radar on the right - Kyle Mills
  * Add autoFlagReset plugin - Chris Wible
  * Allow joystick hats as input on Evdev and SDL platforms - Kyle Mills
  * Added Fastmap Plugin - Jeffery Myers
* Mon Apr 30 2012 reddwarf@opensuse.org
- Use system c-ares and glew
- Stop using autoreconf
* Fri Mar 23 2012 jengelh@medozas.de
- Strip redundant sections/tags from specfile
* Fri Sep 30 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Wed Jul  6 2011 jmcdonough@suse.de
- Update to version 2.4.0
  * Shot messages are synchronized with position
  * Added /playerlist for everyone
  * Added message type for properly handling /me actions
  * Added BZDB option to hide flags on radar server side
  * Removed /setpass /register /identify
  * Handicap is computed on the server
  * Allow plugins to register custom flag types
  * Forced *image.bzflag.org for image downloads until user sets
    otherwise
  * Accepted patch from McSpider, added OpenFFA
  * Removed -requireUDP, now it is always required
  * Accepted patch from McSpider, removed client option to turn off fog
  * Accepted patch from McSpider, added -noTeamKills option
  * Removed -3Dfx, -no3Dfx. Moved -geometry ->  -window <geometry-spec>
  * Add ricochet on a per object basis for .bzw files
  * serverControl plugin- Add option to ignore observers for server shutdowns
  * serverControl plugin- Only report ban file access errors once
  * serverControl plugin- Limit filesystem checks to once every 3 seconds
  * LogDetail plugin-Add SERVER-MAPNAME with the public server description
  * The bzfs -time command line option allows end time
  * screenshots now compressed asynchronously
  * Add /serverdebug command and plugin API
  * Add bzfs -utc command line option to log timestamps using universal time
  * Fix buffer overrun when using -ts micros on Linux
  * Only players with POLL permission are eligible to vote
  * Only allow a single end shot credit for holding the shield flag
  * Do not inform hunters of stealthy prey
  * All scores are controlled completely by the server
  * Relabel player "email" string as "motto"
  * Require TALK privilege for player motto to be broadcast
  * Always require valid authentication for registered names
  * Move flag identification server side
  * GM sanity checks
  * Added the -publickey requirement for publicly listed servers (and renamed
    the bzfs -public option to -publictitle)
- Remove forward declaration patch
* Sat Jul  2 2011 jengelh@medozas.de
- Use %%_smp_mflags for parallel building
- Strip %%clean section (not needed on BS)
* Tue Apr  6 2010 hvogel@novell.com
- Update to version 2.0.16
  * Fix regression in protocol handling by server
  * Add bullet tails as seen out the viewport
  * Remove unused dependency on Xi library
  * Allow only one Enter message per player instance
  * Add TimeLimit plugin
  * Remove broken vocaliser and obsolete torBlock plugins
  * Add Options -> Display -> AntiFlicker option
  * Add Options -> Input -> Confine Mouse (MotionBox)
  * Adjust advanced ground rendering for texture flicker
  * Backport fix for /idbanlist and /hostbanlist crashes
  * Fix player ghosting failure
  * Provide API support for using bz_moveFlag on team flags
  * Add pushstats plugin for future statistics gathering system
  * Increase restrictions on incompletely joined players
  * Announce saved file name in recordmatch plugin
  * Fix buffer overflow in menu subsystem
  * Fully support glob-style wildcards in hostbans and make name comparisons
    case insensitive
  * Properly limit maximum message size in /showgroup command
  * Reset team scores in case of a capture during a countdown
  * Block spoofed /me messages
  * Keep flags within the world boundary
  * Add the "roamView" BZDB variable
  * Change fonts to DejaVu
  * Source cleanup
  * use fdupes
* Thu Mar 18 2010 prusnak@novell.com
- cleanup spec file
* Mon Sep  8 2008 hvogel@suse.de
- Update to 2.0.12
  * Fix for memory leaks
  * Remove extra dir separator from cache entries
  * Configurable "defaultFOV" (60 deg) for widescreen users
  * Queue spawns after flag captures
  * Fix kill callback when is coming from server
  * Various permission fixes
  * gcc-4.3 fixes
* Mon Apr 21 2008 hvogel@suse.de
- update to latest 2.0 branch svn to fix various c-ares bugs
  [bnc#378717]
- add short description to init script
- build against ncurses for bzadmin
* Mon Apr  7 2008 crrodriguez@suse.de
- bzflag no longer uses adns but a bundled copy of libcares,
  update the spec file to use system c-ares instead.
* Wed Jan 16 2008 hvogel@suse.de
- Update to bzflag-2.0.10:
  * Add /modcount command
  * Add -adminlagannounce and -lagannounce
  * First map no longer ignored in Start Server menu
  * Add packet loss kick and related admin commands
  * Plugins get flag resets/spawns/grab/drop/transfer
  * Added more info for observers
  * Optionally use mesh position and height for radar
  * Add various new plugins (rabidRabbit, rabbitTimer torBlock regFlag, etc.)
  * Add favorite server
  * Some API changes
  * Adding jitter kick and related admin commands
  * Ability to change the killer in a PlayerDieEvent
  * Backport the record stop function from 2.1
  * Backported WW GMs from 2.1
* Tue Oct 16 2007 pgajdos@suse.cz
- added missing includes according to new gcc
  * missing-includes.patch
* Mon Apr 16 2007 pgajdos@suse.cz
- fixed 'warning: array subscript is below array bounds' [#229908]
- array_subscript2.patch
* Tue Mar 13 2007 pgajdos@suse.cz
- fixed 'warning: array subscript is below array bounds'
- array_subscript.patch
* Wed Jan 10 2007 hvogel@suse.de
- fix make install issue with mkdir
* Fri Jun 30 2006 duwe@suse.de
- update to upstream version 2.0.8:
  * Add a plugin to record matches
  * Add an option to send out a UDP heartbeat message for observers behind flakey
  routers
  * Replaced admin message sound
  * Client and server now close http connections correctly
  * Fixed crash when rogue autopilot picks up a team flag
  * Fixed spawnpoint selection regression
* Fri May  5 2006 mmj@suse.de
- Devel package is gone
- Update to bzflag-2.0.6:
  o game variables no longer accept invalid values.
  o Special Effects use tank (was team) color
  o /reset uses the values from the config and the map as default
  o Sreenshots now remember where they left off
  o Have windows dump std::error out to a file
  o Various API enhancmentes
  o Not applauding when capturing his own flag
  o Fixing crash on invalid captured flag
  o Fixed bots on a public server
  o Don't send admin the server password when wrong
  o Client config file can be saved on request
  o Allow for longer help files (50 lines)
  o Allow selective /reload of databases
  o Fix wrong kick if pausing having V and moving
  o Prevent long distance tank warping through walls
  o Display paused state when screen capturing while playing
  o Added new logDetail plugin
  o Fixed issue with denial-of-service message attacks
  o Support for -window on Mac command line executions
  o Show slot numbers in lagstats (if admin)
  o FPS limit energy saver option for laptops
  o Send admin channel warning if /password fails
  o Known players not authenticated are detected
  o Added /checkip command
  o "Enable Local Shot/Spawn Effects" affects "Driving with"
  o Show shot reload indicators when driving with a tank
  o Fix misc/bzfquery.pl to handle MsgGameTime
  o Simple server list searching
  o Added GUI option for email display length
* Wed Feb  1 2006 hvogel@suse.de
- fix BZFlag NULL Byte callsign DOS bug [#141121]
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 mmj@suse.de
- Build without SDL support for now, since it's broken [#143932]
* Tue Nov  8 2005 mmj@suse.de
- Split -devel package off for plugin stuff
- Update to 2.0.4 including:
  o Automatic team icon
  o Fixed server join bug when cached worlds disappear
  o Prevent phantom zoned players from pausing
  o Implemented multiple player hunt
  o Directional keys pressing works, even in joy/mouse mode
  o Jitter compensation removed. Too bad behaviour on ME players
  o Put spawn params in BZDB to let server owners mod them as needed
  o Fixed ban admin bug
  o Added /sendhelp command
  o /ban /hostban take time keywords (short ...) too
  o Inertia style indicatio no more used
  o No more restriction on M (Momentum) flag
  o Fixing authentication when changing callsign/password
  o Fixing authentication when joining from command-line
  o Executing abbreviated server command '*' terminated
  o Getting one-line-help on server command '?' terminated
  o Fixing bzflag use of system-wide regex (--without-regex)
  o Adding destination info to chat message log
  o Adding syntax check to duration parameter of ban cmds
  o Hud outlines go transparent with the hud panel
  o Better progress info when downloading textures
  o Add Quake3 BSP import to modeltool
  o Exit BZFS if -g is used with -mts or -mps
  o Experimental server colorizing in server list
  o Added sort options to "/replay list" and "/record list"
  o Map mismatch fixed
  o Quick server command key works better
  o Default server side plugins added to windows build
  o Include web token verification script
  o Fix texture cache on windows.
  o Disallow + or @ as first char of callsign (bzfs)
  o Wait for reverse DNS and authentication to enter game
  o Antiban works even on IP number
  o Sort lagstat to have non-observer at the bottom
  o Authentication credential are requested asap
  o Allow the use of game device sliders as axes on Windows
  o Directional force feedback support
  o New icon and menu arrow
  o Special effects for many events
  o Server-side plugin API and plugins
  o Join menu displays team icon
  o Implemented "-advertise" option for bzfs
  o The url now does not contain the password (sent with POST)
  o Fixing Tiny tank shooting from the world edge
  o Fixing client requesting lan server on some systems
  o Observer are no more hunted
  o Added 'Always Show Team Scores' option (GUI Options Menu)
  o Added beautify scores
  o Added scoreboard sort option
  o Shots fired over the boundary wall end at the wall
  o Increase range of radar size setting in GUI Option menu
  o Fixed Menu rendering when radar size is great
  o Fixed Linux name resolution (server list) problem
  o Fixed Jitter problem on Windows, clock was wrong
  o Windows platform can switch from SDL to native
  o Instruction for X-build from linux to windows
  o bzflag is much less blocking with libcurl
  o Using c-ares instead of adns for DNS resolving
  o Added CTF capture event trigger for world weapons
  o FlipZ on meshpyrs behaves as expected (like pyramids)
  o Fixed /set and /reset command case bug
  o Fixed crash on /ban without -banfile
  o Shot reload timer on the HUD
  o Added timestamp to bzfs DEBUG output, and new CL option (-ts)
  o Players without TALK can send to the Admin group
  o Fixed bzfs crash because poll kick/ban
  o Allow additional group modify permission lines
  o bzfs creates default groups before parsing groupdb file
  o +ALL and -ALL adds/removes all perms from a group in groupdb
  o Support for +,- and ! operators in bzfs' groupdb file
* Tue Oct  4 2005 schwab@suse.de
- Add SDL-devel-packages to neededforbuild.
* Fri Sep 30 2005 stbinner@suse.de
- fixed .desktop file
* Mon Aug 22 2005 hvogel@suse.de
- fix data type comparison [Bug #104607]
* Fri Jul 15 2005 hvogel@suse.de
- Don't compile with -f-signed-char [#93873]
- add curl for MOTD, global bans, etc. (needs bc for the configure
  check *shrug*)
- add libadns for hostmask based bans (needs ssl)
* Thu Jun 23 2005 schwab@suse.de
- Build with -fno-strict-aliasing [#85848].
* Tue Jun  7 2005 mmj@suse.de
- Add sysconfig variable for newbies
* Mon May 23 2005 schwab@suse.de
- Fix missing declaration.
* Wed Mar 30 2005 mmj@suse.de
- Update to 2.0.2 which is a bugfix release
* Tue Jan 18 2005 mmj@suse.de
- Update to 2.0.0 which introduces a slew of major new features
  making this probably the "biggest" release in BZFlag's history
  in terms of development time put into it and features being
  added since the last publicly released version. Major new
  features include support for vastly more complex worlds,
  physics drivers, graphics improvements, weather (rain, snow,
  frogs), tank treads and tracks, animations, record and
  playback, new flags, new commands, optimizations and much more.
  There is a new central registration system, global ban list
  support, network, new cheat preventions, and network
  optimizations in place as well.
* Tue Nov  2 2004 mmj@suse.de
- Update urbancombat map to fit newer BZFlag versions
* Mon Oct 11 2004 mmj@suse.de
- Update to 1.10.8 which is a maintenance release:
  o New list server URL
  o Added admin message sounds
  o Throw away bad or early links in world files
* Sat May 22 2004 mmj@suse.de
- Update to 1.10.6 including:
  o Fixed the little hop on spawn at some sites
  o Fixed issue of players add/removing others from groups
  o Fixed false positive filter matches involving apostrophes
  o Curing ghost/duplicated/ungetable flag
  o Fixed 0 height flag, no more flags inside buildings
  o Observers see Masquerade tank with their true color
  o Password file now supports callsigns with non alphanumerics
  o Correctly read PNG textures with multiple IDAT chunks
  o bans based on hostmask (/hostban, ...) when adns is available
  o Fixed bug that allowed empty callsigns
  o server option to disallow autopilot
  o Bots drive around corners faster
  o Bots aim better, try to evade shots
* Thu Apr 29 2004 mmj@suse.de
- Add missing sample bzflagserver configuration file to the docu-
  mentation
* Tue Jan 27 2004 mmj@suse.de
- Update to 1.10.4
- Undefine bool after ncurses include
* Tue Jan 20 2004 mmj@suse.de
- Add std::streamoff() wrapper (gcc 3.4)
- It's CPPFLAGS and CFLAGS now
* Tue Dec 30 2003 mmj@suse.de
- Run the bzflagserver as nobody:nobody
* Sun Dec 28 2003 mmj@suse.de
- Update to 1.10.2 with a number of bugfixes including the one
  where Guided Missile was not capable of hitting ring 0 players.
* Fri Dec 12 2003 mmj@suse.de
- Adjust the sysconfig file settings
* Thu Dec 11 2003 mmj@suse.de
- Update to 1.10.0 which is incompatible with older versions of
  BZFlag, and brings a tremendous amount of new stuff, including
  new flags.
* Wed Oct 15 2003 mmj@suse.de
- Don't build as root
* Sat Sep 13 2003 sndirsch@suse.de
- fixed icon name in desktop file
* Thu Sep 11 2003 adrian@suse.de
- make the menu texts a bit nicer
- remove unneeded X-SuSE before Categories
* Thu Aug 14 2003 mmj@suse.de
- Add sysconfig activation metadata
* Mon Aug 11 2003 mmj@suse.de
- Add a desktop file and an icon
* Wed Jul 30 2003 mmj@suse.de
- Use new macros for stop/restart of services on rpm update/removal
* Wed Jun 18 2003 mmj@suse.de
- Don't package the stuff in /usr/share/games/bzflag/bzflag
* Wed Jun 18 2003 mmj@suse.de
- Update to 1.7g2
* Mon Jun  2 2003 mmj@suse.de
- Fix typo
* Fri Feb  7 2003 mmj@suse.de
- Add /etc/sysconfig/bzflagserver with parameters for the bzflag
  server.
- Tiny specfile cleanup
* Mon Dec  9 2002 mmj@suse.de
- Update to 1.7g0 which include world file caching, team killers
  die, tank labels on roaming, new GUI options including a
  smaller display for slow systems (set opacity all the way up),
  and much more!
* Thu Nov 14 2002 mmj@suse.de
- Added some maps
* Thu Nov 14 2002 mmj@suse.de
- Make neededforbuild more current
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Thu Aug 15 2002 mmj@suse.de
- Add PreReq for insserv.
* Wed Jul 31 2002 mmj@suse.de
- Remove insserv call
* Sat Jul 27 2002 mmj@suse.de
- Fix specfile for ppc64
* Tue Jul 16 2002 mmj@suse.de
- Update to 1.7e6 which includes:
  o udp request fix for later clients
  o MsgEnter should not be patched for ID
  o Removed superfluous buffer copies in bzfs buffer sends
  o Better pack/unpack code for vectors [3]
  o Fix Teamflag drop over building when building at 0,0,0
  o Fix flags spawning in pyramids
  o Fix client crashes with UNKNOWNS
  o fix patchMessage for MsgAlive
  o fix find closest flag (ID) with flags on buildings
  o scale flags bases on elevation
  o don't scale radar based on screen res
  o flag radar updated
  o new admin commands
  o -pr for reconnect port (two port tcp)
* Sat May 18 2002 schwab@suse.de
- Fix typo in spec file.
* Sat May 18 2002 mmj@suse.de
- Fixed the startup script.
* Fri May 17 2002 mmj@suse.de
- Added a startup script for the BZFlag server, also changed
  Bzflag to BZFlag in all descriptions
* Fri May 10 2002 mmj@suse.de
- Introduce lib64 configure option for the platforms using 64 bit
  libraries.
* Wed Apr 24 2002 schwab@suse.de
- Fix for gcc 3.1.
* Thu Jan 10 2002 ro@suse.de
- no subdirs in /usr/games
* Wed Jan  2 2002 adrian@suse.de
- fix build for mips and arm
* Fri Dec  7 2001 grimmer@suse.de
- update to 1.7e4
* Thu Nov  8 2001 ro@suse.de
- use mesa-devel-packages in neededforbuild
* Wed Jul 11 2001 grimmer@suse.de
- update to 1.7e2
* Mon Jul  9 2001 sndirsch@suse.de
- xdevel3 for #neededforbuild not required any more
* Tue May  8 2001 mfabian@suse.de
- bzip2 sources
* Mon Mar 19 2001 grimmer@suse.de
- Update to version 1.7e1
- created new patch, added wrapper script as separate source
  file
- spec file fixes / cleanups
- removed hard coded requirement on mesa (RPM can take care of that)
* Thu Mar 15 2001 ro@suse.de
- changed neededforbuild <mesaglu> to <xf86glu>
- changed neededforbuild <mesaglu-devel> to <xf86glu-devel>
* Wed Mar  7 2001 ro@suse.de
- changed neededforbuild <mesadev> to <mesa-devel>
* Mon Nov 13 2000 ro@suse.de
- don't redeclare inet_aton
* Tue Aug  1 2000 grimmer@suse.de
- replaced #neededforbuild xdevel with xdevel3
* Mon Jun  5 2000 ro@suse.de
- added mesadev to neededforbuild
* Fri Apr 14 2000 schwab@suse.de
- Use generic linux configuration for ia64.
* Thu Mar 16 2000 grimmer@suse.de
- Update to 1.7d.9
- Added BuildRoot
- added bzfrelay and bzfls (incl. manpages)
* Mon Jan 24 2000 uli@suse.de
- added -D__linux to PC*FLAGS (needed for gcc 2.95)
* Fri Jan 21 2000 grimmer@suse.de
- spec file cleanups (added URL, Group and version macro)
* Fri Jan 21 2000 ro@suse.de
- use _GNU_SOURCE
* Mon Dec 20 1999 kukuk@suse.de
- fixed for SPARC
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Aug 31 1999 uli@suse.de
- fixed for PPC
* Tue Jun 22 1999 grimmer@suse.de
- initial package (Version 1.7c)
